module.exports = {
	env: {
		es6: true,
		browser: true,
		node: true,
		mocha: true,
	},
	extends: ['airbnb'],
	plugins: ['babel', 'import', 'mocha', 'prettier'],
	parser: 'babel-eslint',
	parserOptions: {
		ecmaVersion: 6,
		ecmaFeatures: {},
	},
	globals: {
		// Cannot reassign sm
		require: false,
		sm: false,
		rootRequireFromShared: false,
		rootRequireFromWeb: false,
	},
	rules: {
		indent: ['off', 'tab'],
		'no-tabs': 0,
		'no-empty': 'off',
		'no-empty-pattern': 'off',
		'func-names': 0,
		'no-underscore-dangle': 0,
		semi: 0,
		'getter-return': 'off',
		'no-undef-init': 'off',
		'prefer-const': 'off',
		camelcase: 'off',
		'no-undef': 'off',
		'import/order': 'off',
		'no-useless-constructor': 'off',
		'no-empty-function': 'off',
		'no-cond-assign': 'off',
		quotes: 'off',
		'class-methods-use-this': 'off',
		'array-callback-return': 'off',
		'global-require': 'off',
		'consistent-return': 'off',
		'nonblock-statement-body-position': ['off', 'any'],
		'no-use-before-define': 'off',
		'no-prototype-builtins': 'off',
		eqeqeq: ['off', 'smart'],
		'operator-linebreak': ['off', 'before'],
		'no-unused-vars': 'off',
		'no-shadow': 'off',
		'default-case': 'off',
		'prefer-rest-params': 'off',
		'no-debugger': 'off',

		'no-dupe-class-members': 'error',
		'no-multi-assign': 'error',
		'no-script-url': 'warn',

		'wrap-iife': 'off',

		'no-lone-blocks': 'error',
		'import/no-unresolved': 'error',
		'import/no-extraneous-dependencies': 'error',
		'no-new-object': 'warn',
		strict: 'off',
		'no-multi-spaces': 'off',
		'no-nested-ternary': 'off',
		'no-await-in-loop': 'off',

		'linebreak-style': 'off', // Don't play nicely with Windows.

		'arrow-parens': 'off', // Incompatible with prettier
		'object-curly-newline': 'off', // Incompatible with prettier
		'no-mixed-operators': 'off', // Incompatible with prettier
		'arrow-body-style': 'off', // Not our taste?
		'function-paren-newline': 'off', // Incompatible with prettier
		'no-plusplus': 'off',
		'space-before-function-paren': 0, // Incompatible with prettier
		'one-var-declaration-per-line': 'off',
		'one-var': 'off',
		'object-curly-spacing': 'off',
		'quote-props': 'off',

		'max-len': [
			'off',
			150,
			2,
			{
				ignoreUrls: true,
				ignoreTemplateLiterals: true,
				ignoreRegExpLiterals: true,
				ignoreComments: true,
			},
		], // airbnb is allowing some edge cases
		'no-console': 'off', // airbnb is using warn
		'no-alert': 'off', // airbnb is using warn

		'no-param-reassign': 'off', // Not our taste?
		radix: 'off', // parseInt, parseFloat radix turned off. Not my taste.

		'prefer-destructuring': 'off',
		'prefer-arrow-callback': 'off',
		'prefer-template': 'off',
		'vars-on-top': 'off',
		curly: 'off',
		'no-var': 'off',
		'prefer-spread': 'off',
		'spaced-comment': 'off',
		'no-ex-assign': 'off',
		'object-shorthand': 'off',
		'comma-dangle': 'off',
		'no-else-return': 'off',
		'padded-blocks': 'off',
		'block-spacing': 'off',
		'no-lonely-if': 'off',
		'import/newline-after-import': 'off',
		'keyword-spacing': 'off',
		'no-trailing-spaces': 'off',
		'eol-last': 'off',
		'newline-per-chained-call': 'off',
		'object-property-newline': 'off',
		'no-useless-return': 'off',
		'space-before-blocks': 'off',
		'space-before-blocks': 'off',
		'no-useless-escape': 'off',
		'no-buffer-constructor': 'off',
		'space-in-parens': 'off',
		'no-multiple-empty-lines': 'off',
		'comma-spacing': 'off',
		'no-mixed-spaces-and-tabs': 'off',
		'no-multi-assign': 'off',
		'lines-between-class-members': 'off',
		'guard-for-in': 'off',
		'no-restricted-syntax': 'off',
		'space-infix-ops': 'off',
		'key-spacing': 'off',
		'no-unused-expressions': 'off',
		'no-sequences': 'off',
		'func-call-spacing': 'off',
		'no-spaced-func': 'off',
		'no-unexpected-multiline': 'off',
		'dot-notation': 'off',
		'key-spacing': 'off',
		'block-scoped-var': 'off',
		'no-restricted-globals': 'off',
		'import/no-dynamic-require': 'off',
		'no-new': 'off',
		'arrow-spacing': 'off',
		'no-extra-semi': 'off',
		'lines-around-directive': 'off',
		'no-multi-str': 'off',
		'new-cap': 'warn',
		'no-continue': 'off',
		'no-useless-rename': 'warn',
		'operator-assignment': 'off',
		'no-inner-declarations': 'off',
		'no-unneeded-ternary': 'off',
		'no-extra-boolean-cast': 'off',
		'no-path-concat': 'warn',
		'no-extend-native': 'off',
		'no-confusing-arrow': 'off',
		'no-loop-func': 'off',
		'comma-style': 'off',
		'no-useless-concat': 'off',
		'array-bracket-spacing': 'off',

		'no-dupe-keys': 'error',

		'prettier/prettier': ['warn'],
	},
}
